@@ -14,6 +14,10 @@
 #'augment <- fit(augment, xw)
 #'xa <- transform(augment, xw)
 #'ts_head(xa)
+#'@importFrom daltoolbox dal_transform
+#'@importFrom daltoolbox fit
+#'@importFrom daltoolbox transform
+#'@importFrom daltoolbox adjust_ts_data
 #'@export
 ts_aug_flip <- function() {
   obj <- dal_transform()
@@ -22,6 +26,7 @@ ts_aug_flip <- function() {
   return(obj)
 }
 
+#'@importFrom daltoolbox transform
 #'@export
 transform.ts_aug_flip <- function(obj, data, ...) {
   add.ts_aug_flip <- function(obj, data) {
@@ -35,7 +40,7 @@ transform.ts_aug_flip <- function(obj, data, ...) {
   if (obj$preserve_data) {
     idx <- c(1:nrow(data), attr(result, "idx"))
     result <- rbind(data, result)
-    result <- adjust_ts_data(result)
+    result <- daltoolbox::adjust_ts_data(result)
     attr(result, "idx") <- idx
   }
   return(result)
